/* -- template for a "less dumb" terminal app -- (based on "stk-term" which was a true dumb terminal app)
A new class "TermIO" is included which fields key strokes.
This example is a testbed for AM, FM, etc. and allows real-time change of coefficients for amp and freq of sine oscillators. 
The inner loop runs until a `q' is received by TermIO. */

// pick your audio resolution
#define NCHANS 1
#define SRATE_HZ 48000

#include "RtWvOut.h"
#include "WvOut.h"
#include "TermIO.h"
#include "Tfunc.h"

int
main (void)
{
	TermIO *term = new TermIO (true);						// instantiate the new class (UI window is set up)
	Stk::setSampleRate (SRATE_HZ);
	RtWvOut *rt = new RtWvOut (NCHANS);
	WvOut *outFile = new WvOut ("/zap/test.wav", NCHANS);
	Tfunc *osc = new Tfunc ();
	Tfunc *mod = new Tfunc ();
	#define baseAmp 1.0
	#define baseFreq 440.0
	osc->setAmp(baseAmp);
	osc->setFreq(baseFreq);
	mod->setAmp(baseAmp);
	mod->setFreq(baseFreq);
	double outFrame[NCHANS];
	int i;
	for (i = 0; i < NCHANS; i++)
		outFrame[i] = 0.0;
	/* ------ this is where the real work happens ------ */
	while (!term->quit)	// run until user decides
	{
		term->pollEvent ();									// check for new key stroke
 
//		mod->setFreq(term->coeffF * baseFreq);
		mod->setFreq(term->coeffF);

		for (i = 0; i < NCHANS; i++)
			outFrame[i] = osc->tick(1.0, term->coeffA * mod->tick());		// FM, coeffA is "Modulation Index"
		
		rt->tickFrame (outFrame);
		outFile->tickFrame (outFrame);
	}
	/* ------------------------------------------------ */
	delete term;											// UI window is shut down
	delete rt;
	delete outFile;
	delete osc;
	delete mod;
}


